#[repr(C)]pub struct BridgeConfig<'a> {
input: Buffer,
dispatch: Closure<'a>,
force_show_panics: bool,
}🔬This is a nightly-only experimental API. (
proc_macro_internals)Expand description
Configuration for establishing an active connection between a server and a
client. The server creates the bridge config (run_server in server.rs),
then passes it to the client through the function pointer in the run field
of client::Client. The client constructs a local Bridge from the config
in TLS during its execution (Bridge::{enter, with} in client.rs).
Fields
input: Buffer🔬This is a nightly-only experimental API. (
proc_macro_internals)Buffer used to pass initial input to the client.
dispatch: Closure<'a>🔬This is a nightly-only experimental API. (
proc_macro_internals)Server-side function that the client uses to make requests.
force_show_panics: bool🔬This is a nightly-only experimental API. (
proc_macro_internals)If ‘true’, always invoke the default panic hook